import { useState } from 'react'
import { ImBin } from 'react-icons/im'
import { MdOutlineModeEditOutline } from 'react-icons/md'
import { Modal, Button } from 'react-bootstrap';


const Students = ({ children, marks, onDeleteStudent, id, index }) => {

    const [show, setShow] = useState(false);
    const [deleteShow, setDeleteShow] = useState(false);

    const handleDeleteOpen = () => setDeleteShow(true);
    const handleDeleteClose = () => setDeleteShow(false);

    const handleClose = () => setShow(false);
    const handleShow = () => setShow(true);

    const [text, setText] = useState(children);
    const [mark, setMark] = useState(marks);

    const onEditStudent = async (id) => {
        let item = { text, mark }
        const response = await fetch(`http://localhost:5000/students/${id}`, {
            method: 'PUT',
            headers: {
                'Accept': 'application/json',
                'Content-Type': 'application/json'
            },
            body: JSON.stringify(item)
        })
        const data = await response.json()
        console.log(data);
    }

    return (
        <>
            <div className='student'>
                <div>{index + 1}</div>
                <div>{text}</div>
                <div>{mark}</div>
                <div><small className={`${mark >= 35 ? 'pass' : 'fail'}`}>({mark >= 35 ? 'P' : 'F'})</small></div>
                <div style={{ display: 'flex' }}>
                    <div><MdOutlineModeEditOutline onClick={handleShow} /></div>
                    <div style={{ marginLeft: '10px' }}><ImBin onClick={handleDeleteOpen} /></div>
                </div>
            </div>
            {/* Delete Student */}
            <Modal show={deleteShow} onHide={handleDeleteClose}>
                <Modal.Header closeButton>
                    <Modal.Title>Are you sure you want to delete? <br /> <b>{text}</b></Modal.Title>
                </Modal.Header>
                <Modal.Footer>
                    <Button variant="secondary" onClick={handleDeleteClose}>
                        Cancel
                    </Button>
                    <Button variant="primary" type='submit' onClick={() => onDeleteStudent(id)}>
                        Delete
                    </Button>
                </Modal.Footer>
            </Modal>

            {/* Edit Student */}
            <Modal show={show} onHide={handleClose}>
                <Modal.Header closeButton>
                    <Modal.Title>Edit Student Data</Modal.Title>
                </Modal.Header>
                <Modal.Body>
                    <div className='form-ctrl'>
                        <label>Name</label>
                        <input type='text' value={text} onChange={(e) => setText(e.target.value)} />
                        <label>Mark</label>
                        <input type='text' value={mark} onChange={(e) => setMark(e.target.value)} />
                    </div>
                </Modal.Body>
                <Modal.Footer>
                    <Button variant="secondary" onClick={handleClose}>
                        Cancel
                    </Button>
                    <Button variant="primary" type='submit' onClick={() => onEditStudent(id)}>
                        Save Changes
                    </Button>
                </Modal.Footer>
            </Modal>
        </>
    )
}

export default Students
